# Exchange Rate

## Description

    This exchangerate operation supports the latest exchangerate acquisition from both api providers
    (exchangerate-api: https://www.exchangerate-api.com, alphavantage: https://www.alphavantage.co),
    the specific API limit please refer to the API providers help documentation.

    The preferred pattern is 2, which means that we will request https://www.exchangerate-api.com to
    get the latest exchangerate.

    Remember, please go to the official website to apply for the supplier to open api_key before the
    follow-up process!!

## Installation

You can install this package via pip:

> pip install ran_exchange_rate

## Thanks

    Thank the open service provider:
    
- https://www.exchangerate-api.com
![image](https://www.exchangerate-api.com/img/hr-logo-2022-ldpi-rc.png)
- https://www.alphavantage.co
![image](https://www.alphavantage.co/logo.png/)